package com.rv.im.friend;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.Toast;

import com.ruiwenliu.wrapper.base.BaseBean;
import com.ruiwenliu.wrapper.base.BaseStatusActivity;
import com.ruiwenliu.wrapper.weight.TitleView;
import com.rv.im.ImSetting;
import com.rv.im.R;
import com.rv.im.UserDetailActivity;
import com.rv.im.adapter.FriendSearchListAdapter;
import com.rv.im.bean.AddResultBean;
import com.rv.im.bean.FriendSearchBean;
import com.rv.im.db.service.ChatMessageServiceImp;
import com.rv.im.db.service.FriendServiceImp;
import com.rv.im.db.table.ChatMessage;
import com.rv.im.presenter.AddFriendPresenter;
import com.rv.im.xmpp.ListenerManager;
import com.rv.im.xmpp.listener.ChatMessageListener;
import com.rv.im.xmpp.listener.NewFriendListener;


/*******
 *
 * 添加好友功能
 *
 */
public class AddFriendActivity extends BaseStatusActivity<AddFriendPresenter> implements NewFriendListener {

    private EditText edtSearch;
    private Button btnSearch;

    private RecyclerView recyclerview;

    private FriendSearchListAdapter adapter;

    private String mKeyWord;

    private String userId;
    private String userName;

    private String addhaoyouid = null;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        ListenerManager.getInstance().addNewFriendListener(this);
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        ListenerManager.getInstance().removeNewFriendListener(this);
        setResult(RESULT_OK);
    }

    @Override
    protected int setLayout() {
        return R.layout.activity_add_friend;
    }

    @Override
    protected void initView(Bundle savedInstanceState, TitleView titleView, Intent intent) {
        titleView.setTitle("添加好友");
        btnSearch = findViewById(R.id.btn_search);
        edtSearch = findViewById(R.id.edt_search);
        recyclerview = findViewById(R.id.recyclerview);
        recyclerview.setLayoutManager(new LinearLayoutManager(this, LinearLayout.VERTICAL, false));
        adapter = new FriendSearchListAdapter(null);
        adapter.setListener(new FriendSearchListAdapter.FriendItemClickListener() {
            @Override
            public void showDetail(FriendSearchBean.FriendSearItemBean item) {
                if (item != null)
                    UserDetailActivity.start(getApplicationContext(), item.getUserId());
            }

            @Override
            public void add(FriendSearchBean.FriendSearItemBean item) {
                userId = item.getUserId();
                userName = item.getNickname();
                int fromAddType;
                if (!TextUtils.isEmpty(userName) && userName.contains(mKeyWord)) {
                    fromAddType = 5;
                } else {
                    // 昵称不包含关键字的话就是通过手机号搜索出来的，
                    fromAddType = 4;
                }

                mPresenter.addFriend(userId, fromAddType);
            }
        });
        recyclerview.setAdapter(adapter);
        btnSearch.setOnClickListener(v -> {
            mKeyWord = edtSearch.getText().toString().trim();
            mPresenter.search(mKeyWord);
        });
    }

    private int isyanzheng = 0;// 该好友是否需要验证

    @Override
    public void onShowResult(int requestType, BaseBean result) {
        switch (requestType) {
            case 0:
                FriendSearchBean searchBean = (FriendSearchBean) result;
                if (searchBean != null && searchBean.resultCode == 1 && searchBean.getData() != null && searchBean.getData().size() > 0) {
                    adapter.setNewData(searchBean.getData());
                }
                break;
            case 1:
                AddResultBean addResultBean = (AddResultBean) result;

                if (addResultBean.resultCode == 1 && addResultBean.getData() != null) {
                    if (addResultBean.getData().getType() == 1 || addResultBean.getData().getType() == 3) {
                        isyanzheng = 0;// 需要验证
                        // 需要验证就发送打招呼的消息，
                        ChatMessage message = mPresenter.doSayHello(null, userName, userId);
                        addhaoyouid = message != null ? message.getPackId() : "";
                    } else if (addResultBean.getData().getType() == 2 || addResultBean.getData().getType() == 4) {// 已经是好友了
                        isyanzheng = 1;// 不需要验证
                        ChatMessage message = mPresenter.doSayAddFriend(userName, userId);
                        addhaoyouid = message != null ? message.getPackId() : "";

                    } else if (addResultBean.getData().getType() == 5) {
                        showToast(getString(R.string.add_attention_failed));
                    }
                }
                break;
        }
    }

    @Override
    public void onNewFriendSendStateChange(String toUserId, ChatMessage message, int messageState) {
        if (messageState == ChatMessageListener.MESSAGE_SEND_SUCCESS) {
            msgSendSuccess(message, message.getPackId());
        } else if (messageState == ChatMessageListener.MESSAGE_SEND_FAILED) {
//            msgSendFailed(message.getPacketId());
        }
    }


    // xmpp消息发送成功最终回调到这，
    // 在这里调整ui,
    // 还有存本地数据库，
    public void msgSendSuccess(ChatMessage message, String packet) {
        if (addhaoyouid != null && addhaoyouid.equals(packet)) {
            if (isyanzheng == 0) {// 需要验证
                showToast("打招呼成功，静候回音");

                FriendServiceImp.getInstance(this).addMessage(mPresenter.buildAddFriendMessage(userId, userName, message.getMessageType()));

//                ListenerManager.getInstance().notifyNewFriend(mLoginUserId, message, true);
            } else if (isyanzheng == 1) {
                showToast("好友添加成功");
                // 数据库中添加好友
                FriendServiceImp.getInstance(this).addMessage(mPresenter.buildAddFriendMessage(userId, userName, message.getMessageType()));
                ChatMessageServiceImp.getInstance(this).addMessage(message);

//                FriendDao.getInstance().updateFriendContent(mLoginUserId, mUser.getUserId(), InternationalizationHelper.getString("JXMessageObject_BeFriendAndChat"), XmppMessage.TYPE_TEXT, TimeUtils.sk_time_current_time());
//                ListenerManager.getInstance().notifyNewFriend(mLoginUserId, message, true);

//                loadOthersInfoFromNet();
//                CardcastUiUpdateUtil.broadcastUpdateUi(mContext);
            }
            // 已经是好友了，mFriend不能为空，
//            mFriend = FriendDao.getInstance().getFriend(mLoginUserId, mUserId);
        }
//        else if (addblackid != null && addblackid.equals(packet)) {
//            Toast.makeText(getApplicationContext(), getString(R.string.add_blacklist_succ), Toast.LENGTH_SHORT).show();
//            findViewById(R.id.look_bussic_cicle_rl).setVisibility(View.GONE);
//            mNextStepBtn.setText(InternationalizationHelper.getString("REMOVE"));
//            mNextStepBtn.setOnClickListener(new RemoveBlacklistListener());
//
//            // 更新当前持有的Friend对象，
//            mFriend.setStatus(Friend.STATUS_BLACKLIST);
//            FriendDao.getInstance().updateFriendStatus(message.getOwnerId(), message.getUserId(), mFriend.getStatus());
//            FriendHelper.addBlacklistExtraOperation(message.getOwnerId(), message.getUserId());
//
//            ChatMessage addBlackChatMessage = new ChatMessage();
//            addBlackChatMessage.setContent(InternationalizationHelper.getString("JXFriendObject_AddedBlackList") + " " + mUser.getNickName());
//            addBlackChatMessage.setTimeSend(TimeUtils.sk_time_current_time());
//            FriendDao.getInstance().updateLastChatMessage(mLoginUserId, Friend.ID_NEW_FRIEND_MESSAGE, addBlackChatMessage);
//
//            NewFriendDao.getInstance().createOrUpdateNewFriend(message);
//            NewFriendDao.getInstance().changeNewFriendState(mUser.getUserId(), Friend.STATUS_18);
//            ListenerManager.getInstance().notifyNewFriend(mLoginUserId, message, true);
//
//            CardcastUiUpdateUtil.broadcastUpdateUi(mContext);
//
//            Intent intent = new Intent(this, MainActivity.class);
//            startActivity(intent);
//            finish();
//        } else if (removeblack != null && removeblack.equals(packet)) {
//            Toast.makeText(getApplicationContext(), InternationalizationHelper.getString("REMOVE_BLACKLIST"), Toast.LENGTH_SHORT).show();
//            findViewById(R.id.look_bussic_cicle_rl).setVisibility(View.VISIBLE);
//            mNextStepBtn.setText(InternationalizationHelper.getString("JXUserInfoVC_SendMseeage"));
//            mNextStepBtn.setOnClickListener(new SendMsgListener());
//
//            // 更新当前持有的Friend对象，
//            if (mFriend != null) {
//                mFriend.setStatus(Friend.STATUS_FRIEND);
//            }
//            NewFriendDao.getInstance().ascensionNewFriend(message, Friend.STATUS_FRIEND);
//            FriendHelper.beAddFriendExtraOperation(message.getOwnerId(), message.getUserId());
//
//            ChatMessage removeChatMessage = new ChatMessage();
//            removeChatMessage.setContent(coreManager.getSelf().getNickName() + InternationalizationHelper.getString("REMOVE"));
//            removeChatMessage.setTimeSend(TimeUtils.sk_time_current_time());
//            FriendDao.getInstance().updateLastChatMessage(mLoginUserId, Friend.ID_NEW_FRIEND_MESSAGE, removeChatMessage);
//           /* FriendDao.getInstance().updateFriendContent(mLoginUserId, message.getUserId(),
//                    InternationalizationHelper.getString("JXMessageObject_BeFriendAndChat"), XmppMessage.TYPE_TEXT, TimeUtils.sk_time_current_time());*/
//
//            NewFriendDao.getInstance().createOrUpdateNewFriend(message);
//            NewFriendDao.getInstance().changeNewFriendState(message.getUserId(), Friend.STATUS_24);
//            ListenerManager.getInstance().notifyNewFriend(mLoginUserId, message, true);
//
//            CardcastUiUpdateUtil.broadcastUpdateUi(mContext);
//
//            loadOthersInfoFromNet();
//        } else if (deletehaoyou != null && deletehaoyou.equals(packet)) {
//            Toast.makeText(getApplicationContext(), InternationalizationHelper.getString("JXAlert_DeleteOK"), Toast.LENGTH_SHORT).show();
//
//            FriendHelper.removeAttentionOrFriend(mLoginUserId, message.getUserId());
//
//            ChatMessage deleteChatMessage = new ChatMessage();
//            deleteChatMessage.setContent(InternationalizationHelper.getString("JXAlert_DeleteFirend") + " " + mUser.getNickName());
//            deleteChatMessage.setTimeSend(TimeUtils.sk_time_current_time());
//            FriendDao.getInstance().updateLastChatMessage(mLoginUserId, Friend.ID_NEW_FRIEND_MESSAGE, deleteChatMessage);
//
//            NewFriendDao.getInstance().createOrUpdateNewFriend(message);
//            NewFriendDao.getInstance().changeNewFriendState(mUser.getUserId(), Friend.STATUS_16);
//            ListenerManager.getInstance().notifyNewFriend(mLoginUserId, message, true);
//
//            CardcastUiUpdateUtil.broadcastUpdateUi(mContext);
//
//            Intent intent = new Intent(this, MainActivity.class);
//            startActivity(intent);
//            finish();
//        }
    }


    @Override
    public boolean onNewFriend(ChatMessage message) {
//        if(message.getMessageType() == MessageTypeEnum)
        return false;
    }
}
